<?php
/**
 * WPB Admin Services
 *
 * Handles display and creation of services on admin side
 * @author		Hakan Ozevin
 * @package     WP BASE
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       2.0
 */

if ( !class_exists( 'WpBAdminServices' ) ) {

class WpBAdminServices {

	public $row_number = 0;

	private $colspan = 6;

	/**
     * WP BASE instance
     */
	protected $a = null;

	/**
     * Reference to services_table
     */
	private $table;

	/**
     * Last inserted id saved from $wpdb->insert_id
     */
	private $last_insert_id = 0;

	/**
     * Constructor
     */
	public function __construct() {
		$this->a = BASE();
		$this->table = $this->a->services_table;
		include_once( WPBASE_PLUGIN_DIR . '/includes/admin/service-props.php' );
	}

	/**
     * Add actions and filters
     */
	public function add_hooks() {
		add_filter( 'appointments_business_tabs', array( $this, 'add_services_tab' ), 4 ); 		// Add tab, should have higher priority than Locations
		add_action( 'app_business_services_tab', array( $this, 'render_tab' ) );
		add_action( 'app_save_settings', array( $this, 'save_settings' ) );
		add_action( 'app_save_account_settings', array( $this, 'save_settings' ) );
		add_filter( 'heartbeat_received', array( $this, 'refresh_lock' ), 10, 3 );
		add_action( 'wp_ajax_app_delete_lock_service', array( $this, 'delete_lock' ) );
		add_action( 'wp_ajax_app_start_lock_service', array( $this, 'start_lock' ) );
		add_action( 'app_save_settings', array( $this, 'save_global_settings' ) );
		add_action( 'app_admin_services_after_per', function(){
			if ( BASE('ESF') ) {
				remove_action( 'app_admin_services_after_per', array( BASE('ESF'), 'settings' ), 22 );
			}
		}, 1 );
	}

	/**
	 * Add "services" tab
	 */
	public function add_services_tab( $tabs ) {
		if ( wpb_admin_access_check( 'manage_services', false ) )
			$tabs['services'] =  __('Services', 'wp-base');

		return $tabs;
	}

	/**
	 * Return number of columns
	 */
	public function nof_columns(){

		$tabs	= apply_filters( 'app_admin_services_add_more_tab', array() );
		$count	= $this->colspan;

		if ( $tabs && count( $tabs ) == 1 ) {
			return $count + 2;
		} else {
			return $count;
		}
	}

	/**
	 * Helper to create header of the table
	 * @return integer	Number of columns
	 */
	private function thead( ) {
		$loc_width 	= $this->a->get_nof_locations() ? 16 :10;
		$cat_width 	= $this->a->get_nof_categories() ? 16 : 10;
		$name_width = max( 10, ( 35 - $loc_width - $cat_width ) );
		$colspan 	= 6;
		?>
<thead>
	<tr>
		<th class="app-service-id-th" style="width:6%"><span class="app-service-id"><?php _e( 'ID', 'wp-base' ) ?></span><?php if ( apply_filters( 'app_admin_services_add_more_th', false ) ) $this->add_more_th(); ?></th>
		<th class="app-service-name" style="width:<?php echo $name_width?>%"><abbr title="<?php _e('You must enter a name, otherwise service will not be saved!', 'wp-base' ) ?>"><?php _e( 'Name*', 'wp-base' ) ?></abbr></th>
	<?php if ( BASE('ESF') ) : ?>
		<th class="app-service-internal" style="width:4%"><abbr title="<?php _e('Internal: Service cannot be selected using Services pulldown menu','wp-base') ?>"><?php _e( 'Int', 'wp-base' ) ?></abbr></th>
	<?php $colspan = $colspan +1; endif; ?>
	<?php if ( BASE('Locations') ) : ?>
		<th class="app-service-location" style="width:<?php echo $loc_width?>%"><?php _e( 'Locations', 'wp-base' ) ?></th>
	<?php $colspan = $colspan +1; endif; ?>
	<?php if ( BASE('Categories') ) : ?>
		<th class="app-service-category" style="width:<?php echo $cat_width?>%"><?php _e( 'Categories', 'wp-base' ) ?></th>
	<?php $colspan = $colspan +1; endif; ?>
		<th class="app-service-capacity" style="width:7%"><?php _e( 'Capacity', 'wp-base' ) ?></th>
		<th class="app-service-duration" style="width:6.5%"><?php _e( 'Duration', 'wp-base' ) ?></th>
	<?php if ( BASE('ESF') ) : ?>
		<th class="app-service-break" style="width:6.5%"><?php _e( 'Padding before', 'wp-base' ) ?></th>
		<th class="app-service-break" style="width:6.5%"><?php _e( 'Padding after', 'wp-base' ) ?></th>
	<?php $colspan = $colspan +2; endif; ?>
		<th class="app-service-price" style="width:7%"><?php echo __( 'Price', 'wp-base' ) . ' ('. wpb_format_currency( ). ')' ?></th>
	<?php if ( BASE('ESF') ) : ?>
		<th class="app-service-deposit" style="width:7%"><?php echo __( 'Security Deposit', 'wp-base' ) . ' ('. wpb_format_currency( ). ')' ?></th>
	<?php $colspan = $colspan +1; endif; ?>
		<th class="app-service-page" style="width:10%"><?php _e( 'Description page', 'wp-base' ) ?></th>
	</tr>
</thead>
		<?php
		return $this->colspan = $colspan;
	}

	/**
	 * Render tab
	 * @param $by_worker: Worker is viewing/creating own services
	 */
	public function render_tab( $by_worker = false ) {

		wpb_admin_access_check( ($by_worker ? 'manage_own_services' : 'manage_services') );

		do_action( 'app_admin_services_start_render', $by_worker );

		wpb_add_action_footer( $this );

		$paged		= empty( $_GET['paged'] ) ? 1 : absint( $_GET['paged'] );
		$rpp 		= (int)wpb_setting( 'records_per_page_business', 10 );
		$rpp 		= $rpp > 30 || $rpp < 1 ? 10 : $rpp;	// Limited to 30 services/page
		$startat 	= ($paged - 1) * $rpp;
		$max_id 	= $this->a->db->get_var("SELECT MAX(ID) FROM " . $this->table );

		if ( $by_worker ) {

			$services = $this->a->get_services_owned_by( $by_worker, $startat, $rpp );

			$total = $this->a->nof_services_owned_by( $by_worker );

		} else {
			$services = $this->a->db->get_results( $this->a->db->prepare(
				"SELECT * FROM " . $this->table .
				" ORDER BY sort_order,ID LIMIT  %d,%d", $startat, $rpp ) );

			$total = $this->a->get_nof_services();
		}

		# Preload meta cache as a whole instead of calling one by one
		WpBMeta::update_meta_cache( 'service', wp_list_pluck( $services, 'ID' ) );

		$nav_links = paginate_links( array(
			'base' 		=> wpb_add_query_arg( 'paged', '%#%' ),
			'format' 	=> '',
			'total' 	=> ceil( $total/$rpp ),
			'current' 	=> $paged
		));

	?>
<div id="poststuff" class="metabox-holder">
	<?php
		wpb_desc_infobox( 'service' );

		do_action( 'app_admin_services_after_info' );

	?><form id="add_services_form" class="app-form" method="post" action="<?php echo wpb_add_query_arg( null, null )?>">

		<div id="tabs" class="app-tabs">
			<ul></ul>

			<div class="postbox">
				<h3 class="hndle"><span><?php _e('List of Services', 'wp-base' ) ?></span></h3>

				<?php do_action( 'app_admin_services_before_add_new' ) ?>

				<div class="app-submit-holder">
					<div class="app-submit alignleft" style="width:30%">
						<input type="button" data-what="service" class="app-add-row button-secondary" value="<?php _e( 'Add New Service', 'wp-base' ) ?>" />
					</div>
					<?php do_action( 'app_admin_services_after_add_new' ) ?>

				<?php if ( $nav_links ) : ?>
					<div class="tablenav">
						<div class="tablenav-pages"><?php echo $nav_links ?></div>
					</div>
				<?php endif; ?>
				</div>

				<div style="overflow-x:auto;">
					<table class="app-list-table widefat app-services-table app-table app-crowded fixed" id="services-table" >
					<?php
						$colspan = $this->thead();

						if ( !empty( $services ) ) {
							foreach ( $services as $service ) {
								echo $this->add_row( $service );
								if ( $service->ID > $max_id ) {
									$max_id = $service->ID;
								}
							}
						} else {
						?><tr class="no-entry-defined"><td colspan="<?php echo $colspan ?>"><?php _e( 'No services found', 'wp-base' ) ?></td></tr><?php
						}
						?>
					</table>
				</div>

			</div>

			<?php do_action( 'app_admin_services_after_per', $by_worker ); ?>

			<?php self::global_settings( $by_worker ); ?>

		</div><!-- Tabs -->
		<div class="submit" id="div_save_services">
			<input type="hidden" name="by_worker" value="<?php echo $by_worker;?>" />
			<input type="hidden" class="max-id-for-service" value="<?php echo $max_id;?>" />
			<input type="hidden" name="action_app" value="save_services" />
			<?php wp_nonce_field( 'update_app_settings', 'app_nonce' ); ?>
			<input id="save_services_button" class="button-primary save_services check-empty" type="submit" value='<?php _e( 'Save Services', 'wp-base' ) ?>' />
			&nbsp;&nbsp;
			<?php _e( '<i>Tip: To delete a service, just clear its name and save.</i>', 'wp-base' ); ?>
		</div>
	</form>
</div>
	<?php
	}

	/**
     * Render Global Service Setttings tab
     */
	public function global_settings( $by_worker ) {
		if ( $by_worker )
			return;
	?>
		<div class="postbox">
			<h3 class="hndle">
				<span><?php _e('Global Service Settings','wp-base') ?></span>
			</h3>
			<div class="inside">
				<table class="form-table">

					<?php wpb_setting_yn( 'time_slot_calculus_legacy' ); ?>

					<?php wpb_setting_yn( 'display_service_props' ) ?>

					<tr>
						<th scope="row"><?php WpBConstant::echo_setting_name('description_post_type') ?></th>
						<td>
						<select name="description_post_type">
						<?php
						$dpt = wpb_setting( 'description_post_type', 'page' );
						$post_types = get_post_types( array( 'public' => true ), 'objects' );

						foreach ( $post_types as $post_type ) {
							if ( 'attachment' != $post_type->name ) {
								echo '<option value="'.$post_type->name .'"'. selected( $dpt, $post_type->name, false) . '>'. $post_type->labels->singular_name . '</option>';
							}
						}
						?>
						</select>
						<span class="description app-btm"><?php WpBConstant::echo_setting_desc('description_post_type') ?></span>
						</td>
					</tr>

				</table>
			</div>
		</div>
	<?php
	}

	/**
	 *	Save global service settings
	 */
	public function save_global_settings() {

		$saved = false;

		if ( isset( $_POST["action_app"] ) && 'save_services' == $_POST["action_app"] ) {

			$options = wpb_setting();

			if ( isset( $_POST['preselect_latest_service'] ) ) {
				$options['preselect_latest_service'] = $_POST['preselect_latest_service'];
			}

			if ( isset( $_POST['time_slot_calculus_legacy'] ) ) {
				$options['time_slot_calculus_legacy'] = $_POST['time_slot_calculus_legacy'];
			}

			if ( isset( $_POST['display_service_props'] ) ) {
				$options['display_service_props'] = $_POST['display_service_props'];
			}

			if ( isset( $_POST['description_post_type'] ) ) {
				$options['description_post_type'] = $_POST['description_post_type'];
			}

			if ( $this->a->update_options( $options ) ) {
				$saved = true;
			}
		}

		if ( $saved ) {
			wpb_notice( 'saved' );
		}
	}

	/**
     * Add Entry template to the footer
	 * @since 3.0
     */
	public function footer( ) {
		$id = get_current_user_id().time();
?><script type="text/html" class="app-template-for-service" data-appendto="#services-table" data-id="<?php echo $id ?>">
<?php echo $this->add_row( $id );
?></script><?php
	}

	/**
	 * Add a template row to enter/edit service
	 * @param service: Service object that will be displayed
	 */
	public function add_row( $service ) {
		$this->row_number++;

		$ex 		= isset( $service->ID );
		$n 			= $ex ? $service->ID : $service;
		$sign 		= '';
		$internal	= isset( $service->internal ) ? $service->internal : 0;
		$name		= $ex ? esc_attr( stripslashes( $service->name ) ) : '';
		$capacity 	= $ex ? $this->a->get_capacity( $service->ID ) : '';
		$price		= $ex ? $service->price : '';
		$deposit	= isset( $service->deposit ) ? $service->deposit : '';
		$padding	= !empty( $service->padding ) ? $service->padding : 0;
		$break_time = !empty( $service->break_time ) ? $service->break_time : 0;
		$class 		= $ex ? 'class="app_service_name empty-means-delete"' : '';
		$lock_holder = isset( $service->ID ) ? $this->check_lock( $service->ID ) : 0;
		$classes	= array( 'app-service-tr' );

		if ( $this->row_number % 2 ) {
			$classes[] = 'app-even';
		}
		if ( $lock_holder ) {
			$classes[] = 'app-locked';
		}

		$html  = '<tbody>';
		$html .= '<tr class="'.implode( ' ', $classes ).'" '.(isset( $service->ID ) ? 'id="app-service-tr-'.$service->ID.'"' : '').'>';
		$html .= '<td>';
		$html .= '<span class="app-service-id">' . $n;
		$html  = apply_filters( 'app_admin_services_after_id', $html, $n, $service );

		$html .= '</span>';
		if ( $ex )
			$html  = apply_filters( 'app_admin_services_add_more', $html, $n, $service );
		$html .= '</td>';

		$html .= '<td class="app-lock-column">';
		$html .= '<input type="text" '.$class.' name="services['.$sign.$n.'][name]" value="'.$name.'"';
		$html .= ' title="'.$name.'" placeholder="'.esc_attr(__('Required','wp-base') ) .'" />';
		$html  = apply_filters( 'app_admin_add_field', $html, $n, $service, 'services', 'service_name' );

		if ( isset( $service->ID ) ) {
			if ( $lock_holder ) {
				$lock_holder   = get_userdata( $lock_holder );
				$locked_avatar = get_avatar( $lock_holder->ID, 18 );
				/* translators: %s: User's display name. */
				$locked_text = esc_html( sprintf( __( '%s is editing', 'wp-base' ), $lock_holder->display_name ) );
			} else {
				$locked_avatar = '';
				$locked_text   = '';
			}

			$html .= '<div class="locked-info"><span class="locked-avatar">' . $locked_avatar . '</span> <span class="locked-text">' . $locked_text . "</span></div>\n";
		}

		$html .= '</td>';

		/* Internal */
		if ( BASE('ESF') ) {
			$html .= '<td class="app-internal">';
			$html .= '<input type="checkbox" name="services['.$sign.$n.'][internal]" '.checked( $internal, 1, false).' value="1" />';
			$html .= '</td>';
		}

		$html  = apply_filters( 'app_admin_services_after_internal', $html, $ex, $n, $sign, $service );

		/* Capacity */
		$html .= '<td>';
		if ( !$this->a->is_package( $n ) ) {
			$html .= '<input class="app-50" type="text" name="services['.$sign.$n.'][capacity]" value="'.$capacity.'" />';
			if ( $ex ) {
				if ( $capacity )
					$html .= '<span class="app-b"> ['. $capacity .']</span>';
				else
					$html .= '<abbr class="app-error" title="'.__('Warning: Check service providers assigned to this service','wp-base').'" style="font-size:10px;"> ['. $capacity .']</abbr>';
			}
		}
		$html .= '</td>';

		$html .= '<td>';
		$html .= $this->duration_selection( $service, $sign.$n );
		$html .= '</td>';

		if ( BASE( 'ESF' ) ) {
			if ( !$this->a->is_package( $n ) && !$this->a->is_daily( $n ) ) {

				$html .= '<td>';
				$html .= $this->padding_selection( $service, $sign.$n, 'before' );
				$html .= '</td>';

				$html .= '<td>';
				$html .= $this->padding_selection( $service, $sign.$n, 'after' );
				$html .= '</td>';

			} else {
				$html .= '<td></td><td></td>';
			}
		}

		/* Price */
		$html .= '<td>';
		$html .= '<input class="app-service-price" type="text" name="services['.$sign.$n.'][price]" value="'.$price.'" />';
		$html .= '</td>';

		if ( BASE('ESF') ) {
			/* Deposit */
			$html .= '<td>';
			$html .= '<input class="app-service-deposit" type="text" name="services['.$sign.$n.'][deposit]" value="'.$deposit.'" />';
			$html .= '</td>';
		}

		/* Description page */
		$pages = wpb_get_description_pages( wpb_setting( 'description_post_type', 'page' ) );

		$html .= '<td class="app-service-page">';
		$html .= '<select class="app-page-selection" name="services['.$sign.$n.'][page]">';
		$html .= '<option value="0">'. __('None','wp-base') .'</option>';
		foreach( (array)$pages as $page ) {
			$s = !empty( $service->page ) && $service->page == $page->ID ? ' selected="selected"' : '';
			$html .= '<option value="'.$page->ID.'"'.$s.'>'. esc_html( $page->post_title ) . '</option>';
		}
		$html  = apply_filters( 'app_admin_services_after_description_page_options', $html, $sign.$n, $service );
		$html .= '</select>';
		$html .= '</td>';

		$html .= '</tr>';
		$html .= '</tbody>';

		/* Add More tabs */
		if ( $ex ) {
			$tabs = apply_filters( 'app_admin_services_add_more_tab', array() );
			if ( !empty( $tabs ) ) {
				$html .= '<tbody class="service-tabs-container" style="display:none">';
				if ( count($tabs) > 1 ) {
					$html .= "<tr class='app-service-tab-head' data-service-id='service-{$n}' >";
					$html .= '<th colspan="2" rowspan="2">';
					$html .= '<ul>';
					foreach ( $tabs as $tab => $name ) {
						# $tab is class_name and $n is service ID
						$html .= "<li><a href='#{$tab}_{$n}'><span class='tab-title'>{$name}</span></a></li>";
					}
					$html .= '</ul>';
					$html .= '</th><td colspan="'.($this->nof_columns()-2).'"></td>';
					$html .= '</tr>';
				}
			}

			$html = apply_filters( 'app_admin_services_after_tr', $html, $sign.$n, $service );

			if ( !empty( $tabs ) )
				$html .= '</tbody >';
		}

		return apply_filters( 'app_services_add_service', wpb_beautify( $html ), $sign.$n, $service );
	}

	/**
     * Helper to create duration select menu
	 * @since 3.0
     */
	private function duration_selection( $service, $n ) {
		$min_time	= $this->a->get_min_time();
		$selections	= wpb_service_duration_selections();
		$duration	= !empty( $service->duration ) ? $service->duration : 0;
		$class		= ( $duration % $min_time != 0 || $duration > max( $selections ) ) ? 'class="error"': '';

		$html = '<select '.$class.' name="services['.$n.'][duration]" >';

		foreach ( $selections as $val ) {
			$text = $val == 1440 ? __( 'All day', 'wp-base' ) : wpb_format_duration( $val );

			$html .= '<option value="'.$val.'"'. selected( $val, $duration, false ).'>'. esc_attr( $text ) . '</option>';
		}
		$html .= '</select>';

		return $html;
	}

	/**
     * Helper to create padding select menu
	 * @since 3.0
     */
	private function padding_selection( $service, $n, $context ) {
		if ( 'before' === $context ) {
			$padding = !empty( $service->padding ) ? $service->padding : 0;
			$name = 'padding';
		} else if ( 'after' === $context ) {
			$padding = !empty( $service->break_time ) ? $service->break_time : 0;
			$name = 'break_time';
		}

		$min_time	= $this->a->get_min_time();
		$k_max		= (int)(1440/$min_time);
		$class		= ($padding % $min_time != 0) ? 'class="error"': '';

		$html = '<select '.$class.' name="services['.$n.']['.$name.']" >';

		for ( $k = 0; $k <= $k_max; $k++ ) {
			$val = $k * $min_time;
			$html .= '<option value="'.$val.'"'.selected( $padding, $val, false ).'>'. wpb_format_duration( $val ) . '</option>';
		}
		$html .= '</select>';

		return $html;
	}

	/**
     * Add more/less to th
	 * @since 2.0
     */
	public function add_more_th( ) {
		// If we are calling this action, we would want to add more/less control under ID too
		if ( !has_action( 'app_admin_services_add_more' ) )
			add_filter( 'app_admin_services_add_more', array( $this, 'add_more' ), 10, 3 );	// Add more link to service ID th
	}

	/**
     * Add more/less link to services tab, under ID td
	 * @since 2.0
     */
	public function add_more( $html, $n, $service ) {

		$html .= '<div class="app-more">';
		$html .= '<span class="dashicons dashicons-arrow-down app-lts-more">&nbsp;</span>';
		$html .= '<a title="'.__( "Click to display/hide more settings by Addons", 'wp-base' ).'" href="javascript:void(0)" class="app-lts-more">';
		$html .=  __( 'More', 'wp-base' );
		$html .= '</a>';
		$html .= '</div>';

		return $html;
	}

	/**
	 * Admin save service settings
	 */
	public function save_settings() {

		if ( isset( $_POST['app_nonce'] ) && !wp_verify_nonce( $_POST['app_nonce'], 'update_app_settings' ) ) {
			wpb_notice( 'unauthorised', 'error' );
			return;
		}

		if ( empty( $_POST["services"] ) ) {
			return;
		}

		if ( !('save_services' == $_POST["action_app"] && is_array( $_POST["services"] )) ) {
			return;
		}

		$by_worker	= !empty( $_POST['by_worker'] );

		if ( (!$by_worker && !wpb_admin_access_check( 'manage_services', false )) ||
			($by_worker && !wpb_admin_access_check( 'manage_own_services', false )) ) {
			wpb_notice( 'unauthorised', 'error' );
			return;
		}

		$max_vars = @ini_get( "max_input_vars" );

		if ( count( $_POST, COUNT_RECURSIVE ) >= $max_vars ) {
			wpb_notice( sprintf(
					__( 'Warning! Input variables exceeded %1$d. Some part of your setting might not be saved. Either decrease "%2$s" setting or increase "Maximum input variables" PHP setting.', 'wp-base' ),
					$max_vars,
					WpBConstant::get_setting_name('records_per_page_business')
				), 'error' );
		}

		do_action( 'app_services_save_pre' );

		$current_uid = get_current_user_id();
		$result = $updated = $inserted = false;

		# To arrange sort among pages, add 100 per page
		$page_add	= empty( $_GET['paged'] ) ? 0 : ( absint( $_GET['paged'] ) - 1 ) * 100;
		$max_sort	= $this->a->db->get_var( "SELECT MAX(sort_order) FROM " . $this->table );

		if ( $by_worker ) {

			$max_sort		 = $max_sort ? $max_sort + 1 : 1;
			$max_sort_not_us = (int)$this->a->db->get_var( $this->a->db->prepare(
					"SELECT MAX(sort_order) FROM " . $this->table.
					" WHERE ID NOT IN ( SELECT object_id FROM ".$this->a->meta_table.
					" WHERE meta_type='service' AND meta_key='created_by' AND meta_value=%d ) ",
					get_current_user_id()
			) );
		}

		$i = 0;	# For sort_order
		foreach ( $_POST["services"] as $ID => $service ) {
			$ID 	 = (int)$ID;
			$r		 = false;
			$pro_arr = array();

			if ( trim( $service["name"] ) ) {
				if ( BASE('ESF') ) {
					$pro_arr = array(
						'padding'	=> isset($service["padding"]) ? preg_replace("/[^0-9]/", "", $service["padding"]) : '',
						'break_time'=> isset($service["break_time"]) ? preg_replace("/[^0-9]/", "", $service["break_time"]) :'',
						'internal'	=> isset($service["internal"]) ? 1 : 0,
						'deposit'	=> isset($service["deposit"]) ? wpb_sanitize_price( $service["deposit"] ) : '',
						'categories'=> isset($service['categories']) && is_array($service['categories']) ? wpb_implode($service['categories']) : '',
					);
				}

				if ( BASE('Locations') ) {
					$locs		= !empty($service['locations']) && is_array($service['locations']) ? wpb_implode($service['locations']) : '';
					$pro_arr 	= array_merge( $pro_arr, array('locations' => $locs ) );
				}

				# Update or insert?
				# Fix sort_order since only partial services will be sent
				if ( $existing = $this->existing( $ID ) ) {
					if ( $by_worker ) {
						if ( $existing->sort_order < $max_sort_not_us )
							$order = $existing->sort_order;
						else
							$order = $max_sort_not_us + 1 + $i + $page_add;
					} else {
						$order = $i + $page_add;
					}

					if ( $r = $this->update( $ID, $service, $pro_arr, $order ) ) {
						$result = true;
					}

				} else {
					$order = $i + $max_sort;

					if ( $r = $this->insert( $ID, $service, $pro_arr, $order ) ) { # ID is irrelevant here
						$result = true;
						$ID = $this->last_insert_id;
					}
				}

				# Assign worker to the service
				if ( $r && $ID && $by_worker && wpb_is_worker( ) && 'yes' == wpb_setting('allow_worker_create_service') ) {
					$this->assign2owner( $ID );
				}

			} else if ( $this->existing( $ID ) ) {
				# Entering an empty name for an existing ID means attempt to delete a service
				$result = $this->delete( $ID );
			}

			$i++;
		}

		if ( $result ) {
			wpb_notice( 'saved' );

			update_user_meta( $current_uid, 'app_service_check_needed',  true );

			# Calculate min time
			wpb_flush_cache();
			$options = wpb_setting();
			$options['calc_min_time'] = $this->a->find_optimum_time_base();
			$this->a->update_options( $options );
		}
	}

	/**
	 * Find exiting service object
	 * @param $ID 	integer			Service object
	 * @return object
	 */
	private function existing( $ID ) {
		return $ID > 0
				? $this->a->db->get_row( $this->a->db->prepare( "SELECT * FROM " . $this->table . " WHERE ID=%d", $ID ) )
				: false;
	}

	/**
	 * Do update
	 */
	private function update( $ID, $service, $pro_arr, $order ) {
		$r = $this->a->db->update( $this->table,
					array_merge( $pro_arr, array(
						'sort_order'=> $order,
						'name'		=> $service["name"],
						'capacity'	=> isset($service["capacity"]) ? preg_replace("/[^0-9]/", "", $service["capacity"]) :'',
						'duration'	=> $service["duration"],
						'price'		=> wpb_sanitize_price( $service["price"] ),
						'page'		=> $service["page"],
					) ),
					array( 'ID'		=> $ID )
				);

		do_action( 'app_service_maybe_updated', $ID, $r );

		return $r;
	}

	/**
	 * Do insert
	 */
	private function insert( $ID, $service, $pro_arr, $order ) {
		$r = $this->a->db->insert( $this->table,
			array_merge( $pro_arr, array(
				'sort_order'=> $order,
				'name'		=> $service["name"],
				'capacity'	=> isset($service["capacity"]) ? preg_replace("/[^0-9]/", "", $service["capacity"]) :'',
				'duration'	=> $service["duration"],
				'price'		=> wpb_sanitize_price( $service["price"] ),
				'page'		=> $service["page"],
				'categories'=> isset($service['categories']) && is_array($service['categories']) ? wpb_implode($service['categories']) : '',
				) )
			);

		if ( $r ) {
			$ID = $this->last_insert_id = $this->a->db->insert_id;

			$_new_service = new WpB_Service( $ID );
			$_new_service->add_created_by();
			$_new_service->add_owner();
			$_new_service->add_created_at();
			$_new_service->add_managed_by();

			do_action( 'app_new_service_added', $ID );
		}

		return $r;
	}

	/**
	 * Delete a service by submitting empty name
	 */
	private function delete( $ID ) {
		$s			= new WpB_Service( $ID );
		$can_delete = wpb_setting('allow_worker_delete_service'); # yes, no, if_empty
		$is_owner	= ! empty( $_POST['by_worker'] ) && ( $_POST['by_worker'] == $s->get_created_by() );
		$has_auth 	= wpb_admin_access_check( 'delete_services', false ) || ( $is_owner && wpb_admin_access_check( 'delete_own_services', false ));

		if ( ! $has_auth ) {
			wpb_notice( 'unauthorised', 'error' );
			return false;
		}

		if ( ! empty( $_POST['by_worker'] ) ) {

			if ( ! $is_owner ) {
				wpb_notice( 'unauthorised', 'error' );
				return false;
			}

			if ( ! in_array( $can_delete, array( 'yes', 'if_empty' ) ) ) {
				wpb_notice( __('Deletion is turned off by admin.','wp-base'), 'error' );
				return false;
			}

			if ( 'if_empty' == $can_delete && $this->has_booking( $ID ) ) {
				wpb_notice( 'unauthorised', 'error' );
				return false;
			}
		}

		if ( apply_filters( 'app_service_skip_delete', false, $ID ) ) {
			return false;
		}

		if ( $res = wpb_delete_service( $ID ) ) {
			# Update related bookings
			$bookings_affected = $this->a->db->query( $this->a->db->prepare(
					"UPDATE ". $this->a->app_table .
					" SET service=0, status='removed' WHERE ID=%d",
					$ID
			));

			wpb_flush_cache();

			do_action( 'app_service_deleted', $ID, $bookings_affected );

		} else {
			wpb_notice( __('Deletion failed.','wp-base'), 'error' );
		}

		return $res;
	}

	/**
	 * Check if there are bookings using the service
	 */
	private function has_booking( $ID ) {
		return (bool)$this->a->db->get_var( $this->a->db->prepare(
					"SELECT COUNT(ID) FROM " .$this->a->app_table. 	" WHERE service=%d AND status<>'test'",
					$ID
		) );
	}

	/**
	 * Assign service to worker who also submitted it
	 */
	private function assign2owner( $ID ) {
		$current_uid = get_current_user_id();

		$sp = $this->a->db->get_var( $this->a->db->prepare(
				"SELECT services_provided FROM " . $this->a->workers_table . " WHERE ID=%d",
				$current_uid
		) );

		$sp_arr = wpb_explode( $sp );
		$sp_arr[] = $ID;

		return $this->a->db->update( $this->a->workers_table,
					array( 'services_provided'	=> wpb_implode( $sp_arr ) ),
					array( 'ID' 				=> $current_uid )
		);
	}

	/**
	 * Start locking when a service selection is opened
	 * @since 3.6.0
	 * @return	json response
	 */
	public function start_lock(){
		$sid = !empty( $_POST['service_id'] ) ? wpb_clean( $_POST['service_id'] ) : 0;

		if ( $sid ) {
			wpb_delete_service_meta( $sid, '_edit_lock' );
			$this->set_lock( $sid );
		}

		wp_send_json_success();
	}

	/**
	 * Set lock for the service record
	 * @param $sid		integer		Service ID
	 * @since 3.6.0
	 * @return	string
	 */
	private function set_lock( $sid ) {
		if ( ! $sid ) {
			return false;
		}

		$user_id = get_current_user_id();
		if ( 0 == $user_id ) {
			return false;
		}

		$now  = $this->a->_time;
		$lock = "$now:$user_id";

		wpb_update_service_meta( $sid, '_edit_lock', $lock );

		return array( $now, $user_id );
	}

	/**
	 * Check if service record is locked
	 * @param $sid		integer		Service ID
	 * @since 3.6.0
	 * @return int|false|null   ID of the user with lock. False if the post does not exist, post is not locked,
	 *                   		the user with lock does not exist. null if the post is locked by current user.
 	 */
	private function check_lock( $sid ) {
		if ( ! $sid ) {
			return false;
		}

		$lock = wpb_get_service_meta( $sid, '_edit_lock' );

		if ( ! $lock ) {
			return false;
		}

		$lock = explode( ':', $lock );
		$time = $lock[0];
		if ( isset( $lock[1] ) ) {
			$user = $lock[1];
		} else if ( $maybe_elast =  wpb_get_service_meta( $sid, '_edit_last' ) ) {
			$maybe_elast = explode( ':', $maybe_elast );
			$user = isset( $maybe_elast[1] ) ? $maybe_elast[1] : 0;
		} else {
			$user = 0;
		}

		if ( ! get_userdata( $user ) ) {
			return false;
		}

		$time_window = apply_filters( 'wp_check_post_lock_window', 30 );
		$time_window = apply_filters( 'app_check_service_lock_window', $time_window );

		if ( $time && $time > $this->a->_time - $time_window && $user != get_current_user_id() ) {
			return $user;
		}

		if ( $user == get_current_user_id() ) {
			return null;
		}

		return false;
	}

	/**
	 * Check lock status on the service record and refresh the lock
	 *
	 * @since 3.6.0
	 *
	 * @param array  $response  The Heartbeat response.
	 * @param array  $data      The $_POST data sent.
	 * @param string $screen_id The screen id.
	 * @return array The Heartbeat response.
	 */
	public function refresh_lock( $response, $data, $screen_id ) {
		if ( ! array_key_exists( 'app-check-locked-service', $data ) ) {
			return $response;
		}

		$received = $data['app-check-locked-service'];
		$checked     = array();

		if ( empty ( $received ) || !is_array( $received ) ) {
			return $response;
		}

		foreach ( $received as $key ) {

			$sid = absint( substr( $key, 15 ) );

			$user_id = $this->check_lock( $sid );
			$user    = get_userdata( $user_id );

			if ( null === $user_id ) {
				$editing = !empty( $data['app-refresh-locked-service'] ) ? $data['app-refresh-locked-service'] : array();
				if ( in_array( 'app-tr-'. $sid, $editing ) ) {
					if ( $new_lock = $this->set_lock( $sid ) ) {
						$checked[$sid]['new_lock'] = implode( ':', $new_lock );
					}
				}
			} else if ( $user ) {
				$send = array(
					/* translators: %s: User's display name. */
					'text' => sprintf( __( '%s is editing', 'wp-base' ), $user->display_name ),
				);

				$avatar = get_avatar( $user->ID, 18 );
				if ( $avatar ) {
					if ( preg_match( "|src='([^']+)'|", $avatar, $matches ) ) {
						$send['avatar_src'] = $matches[1];
					}
				}

				$checked[$sid] = $send;
			}

			$response['app-check-locked-service'] = $checked;
		}

		return $response;
	}

	/**
	 * Delete lock when a record is closed
	 * @since 3.6.0
	 */
	public function delete_lock() {
		if ( ! check_ajax_referer( 'inline_edit', 'ajax_nonce', false ) ) {
			die( json_encode( array( 'error' => $this->a->get_text('unauthorised') ) ) );
		}

		$sid = ! empty( $_POST['service_id'] ) ? wpb_clean( $_POST['service_id'] ) : 0;
		$user_id = $this->check_lock( $sid );
		if ( null === $user_id ) {
			wpb_delete_service_meta( $sid, '_edit_lock' );
		}

		wp_send_json_success();
	}

}

	BASE('AdminServices')->add_hooks();
}